"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateListRepositories = void 0;
const CodeartifactClient_1 = require("../CodeartifactClient");
const ListRepositoriesCommand_1 = require("../commands/ListRepositoriesCommand");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new ListRepositoriesCommand_1.ListRepositoriesCommand(input), ...args);
};
async function* paginateListRepositories(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.nextToken = token;
        input["maxResults"] = config.pageSize;
        if (config.client instanceof CodeartifactClient_1.CodeartifactClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected Codeartifact | CodeartifactClient");
        }
        yield page;
        const prevToken = token;
        token = page.nextToken;
        hasNext = !!(token && (!config.stopOnSameToken || token !== prevToken));
    }
    return undefined;
}
exports.paginateListRepositories = paginateListRepositories;
